@@ -119,7 +119,6 @@ private Q_SLOTS:
     void init()
     {
         view = new QQuickView();
-        view->engine()->addImportPath(BUILT_PLUGINS_DIR);
         view->setSource(QUrl::fromLocalFile(DASHVIEWSTEST_FOLDER "/listviewwithpageheadertest.qml"));
         lvwph = dynamic_cast<ListViewWithPageHeader*>(view->rootObject()->findChild<QQuickFlickable*>());
         model = view->rootObject()->findChild<QQmlListModel*>();
@@ -973,9 +972,15 @@ private Q_SLOTS:
         QCOMPARE(lvwph->contentY(), 1258.);
         QCOMPARE(lvwph->m_headerItemShownHeight, 0.);
 
-        changeContentY(-1700);
-
+        changeContentY(-800);
+        QTRY_COMPARE(lvwph->m_visibleItems.count(), 5);
+        changeContentY(-400);
+        QTRY_COMPARE(lvwph->m_visibleItems.count(), 8);
+        changeContentY(-200);
+        QTRY_COMPARE(lvwph->m_visibleItems.count(), 10);
+        changeContentY(-300);
         QTRY_COMPARE(lvwph->m_visibleItems.count(), 12);
+
         QCOMPARE(lvwph->m_firstVisibleIndex, 0);
         verifyItem(0, -308., 75., true);
         verifyItem(1, -233., 75., true);
@@ -1654,7 +1659,7 @@ private Q_SLOTS:
 
     void addingRemoveItemsShouldNotChangeContentY()
     {
-        QSignalSpy spy(lvwph, SIGNAL(contentYChanged()));
+        QSignalSpy spy(lvwph, &ListViewWithPageHeader::contentYChanged);
         QMetaObject::invokeMethod(model, "insertItem", Q_ARG(QVariant, 0), Q_ARG(QVariant, 150));
         QMetaObject::invokeMethod(model, "removeItems", Q_ARG(QVariant, 1), Q_ARG(QVariant, 6));
 
